==> libgetdata_0.10.0.orig.tar.xz: libgetdata-0.10.0/test/alter_window_op.c <==
/* Copyright (C) 2016, 2017 D.V. Wiebe
 *
 ***************************************************************************
 *
 * This file is part of the GetData project.
 *
 * GetData is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * GetData is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with GetData; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "test.h"

int main(void)
{
  const char *filedir = "dirfile";
  const char *format = "dirfile/format";
  gd_triplet_t threshold;
  int e1, e2, e3, r = 0;
  DIRFILE *D;
  gd_entry_t e;

  rmdirfile();
  mkdir(filedir, 0700);

  MAKEFORMATFILE(format, "w WINDOW in1 in2 EQ 0\n");

  D = gd_open(filedir, GD_RDWR | GD_VERBOSE);

  threshold.r = 4.3;
  e1 = gd_alter_window(D, "w", NULL, NULL, GD_WINDOP_GT, threshold);
  CHECKI(e1, 0);

  gd_entry(D, "w", &e);
  CHECKF(e.EN(window,threshold.r), 4.3);
  gd_free_entry_strings(&e);

  threshold.u = 0x1010;
  e2 = gd_alter_window(D, "w", NULL, NULL, GD_WINDOP_SET, threshold);
  CHECKI(e2, 0);

  gd_entry(D, "w", &e);
  CHECKF(e.EN(window,threshold.u), 0x1010);
  gd_free_entry_strings(&e);

  threshold.i = 333;
  e3 = gd_alter_window(D, "w", NULL, NULL, GD_WINDOP_NE, threshold);
  CHECKI(e3, 0);

  gd_entry(D, "w", &e);
  CHECKF(e.EN(window,threshold.u), 333);
  gd_free_entry_strings(&e);

  gd_discard(D);

  unlink(format);
  rmdir(filedir);

  return r;
}

==> libgetdata_0.11.0.orig.tar.xz: libgetdata-0.11.0/test/alter_window_op.c <==
/* Copyright (C) 2016, 2017 D.V. Wiebe
 *
 ***************************************************************************
 *
 * This file is part of the GetData project.
 *
 * GetData is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * GetData is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with GetData; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
#include "test.h"

int main(void)
{
  const char *filedir = "dirfile";
  const char *format = "dirfile/format";
  gd_triplet_t threshold;
  int e1, e2, e3, r = 0;
  DIRFILE *D;
  gd_entry_t e;

  rmdirfile();
  mkdir(filedir, 0700);

  MAKEFORMATFILE(format, "w WINDOW in1 in2 EQ 0\n");

  D = gd_open(filedir, GD_RDWR | GD_VERBOSE);

  threshold.r = 4.3;
  e1 = gd_alter_window(D, "w", NULL, NULL, GD_WINDOP_GT, threshold);
  CHECKI(e1, 0);

  gd_entry(D, "w", &e);
  CHECKF(e.EN(window,threshold.r), 4.3);
  gd_free_entry_strings(&e);

  threshold.u = 0x1010;
  e2 = gd_alter_window(D, "w", NULL, NULL, GD_WINDOP_SET, threshold);
  CHECKI(e2, 0);

  gd_entry(D, "w", &e);
  CHECKI(e.EN(window,threshold.u), 0x1010);
  gd_free_entry_strings(&e);

  threshold.i = 333;
  e3 = gd_alter_window(D, "w", NULL, NULL, GD_WINDOP_NE, threshold);
  CHECKI(e3, 0);

  gd_entry(D, "w", &e);
  CHECKI(e.EN(window,threshold.u), 333);
  gd_free_entry_strings(&e);

  gd_discard(D);

  unlink(format);
  rmdir(filedir);

  return r;
}
